@@ -65,8 +65,10 @@ set_default_cred_helper <- function(){
       credential_helper_get()
     }, error = function(...){
       tryCatch({
-        helper <- credential_helper_list()[1]
-        credential_helper_set(helper, global = TRUE)
+        helpers <- credential_helper_list()
+        if(identical(.Platform$OS.type, 'windows') && 'credential-manager' %in% helpers)
+          helpers <- 'credential-manager'
+        credential_helper_set(helpers[1], global = TRUE)
       }, error = function(e){
         packageStartupMessage(e$message)
       })
